<template>
    <div class="player-wrapper">
        <div class="player-window-wrapper">
            <div id="player" class="h5-play-wrap"></div>
        </div>
        <div class="tool-bar-wraper flex-end" v-if="showFull || showWdn">
            <el-popover
                placement="top"
                width="200"
                trigger="click"
                popper-class="window-type"
            >
                <div class="flex-center">
                    <i
                        class="btn-icon iconfont icon-sfz-fp1x1"
                        title="1x1"
                        @click="onChangeWdnNum(1)"
                    ></i>
                    <i
                        class="btn-icon iconfont icon-sfz-fp2x2"
                        title="2x2"
                        @click="onChangeWdnNum(2)"
                    ></i>
                    <i
                        class="btn-icon iconfont icon-sfz-fp3x3"
                        title="3x3"
                        @click="onChangeWdnNum(3)"
                    ></i>
                    <i
                        class="btn-icon iconfont icon-sfz-fp4x4"
                        title="4x4"
                        @click="onChangeWdnNum(4)"
                    ></i>
                </div>
                <i
                    slot="reference"
                    class="btn-icon el-icon-s-grid"
                    v-if="showWdn"
                ></i>
            </el-popover>

            <i
                v-if="showFull"
                class="btn-icon el-icon-rank"
                @click="onSetFull"
            ></i>
        </div>
    </div>
</template>

<script>
const MSE_IS_SUPPORT = !!window.MediaSource // 是否支持mse
const portal = window.context.portal
export default {
    name: 'videoPlayerDH',
    props: {
        wrapperName: {
            type: String,
            default: 'h5-play-wrap',
        },
        showWdn: {
            type: Boolean,
            default: true,
        },
        showFull: {
            type: Boolean,
            default: true,
        },
        maxSplit: {
            type: Number,
            default: 4,
        },
        currentSplit: {
            type: Number,
            default: 2,
        },
    },
    data() {
        return {
            player: null,
            videoinfo: '',
            urls: {
                realplay: '',
            },
            mode: MSE_IS_SUPPORT ? 0 : 1,
        }
    },
    mounted() {
        this.createPlayer()
    },
    methods: {
        getVideoURL(val) {
            if (!val) return (this.videoinfo = '暂无视频')
            this.videoinfo = '视频加载中...'
            let query = {
                cameraIndexCode: val, // '50035800001310713876', // 监控点编码
            }
            this.$http
                .post(portal + '/cameras/manager/v1/getPreviewURLs', query)
                .then((res) => {
                    if (res.data.state && res.data.value) {
                        let data = JSON.parse(res.data.value)
                        this.urls.realplay = data.url
                        this.realplay()
                    } else {
                        this.videoinfo = '获取监控点资源失败！'
                        this.$message.warning('获取监控点资源失败！')
                    }
                })
        },
        realplay() {
            let {player, mode, urls} = this,
                index = player.currentWindowIndex,
                playURL = urls.realplay

            console.log(player, 'player')
            player
                .JS_Play(
                    playURL,
                    {
                        playURL,
                        mode,
                    },
                    index
                )
                .then(
                    () => {
                        console.log('realplay success')
                    },
                    (e) => {
                        this.videoinfo = '播放失败，请重试!'
                        console.error(e)
                    }
                )
        },
        stopPlay() {
            this.player.JS_Stop().then(
                () => {
                    this.playback.rate = 0
                    console.log('stop realplay success')
                },
                (e) => {
                    console.error(e)
                }
            )
        },
        init() {
            // 设置播放容器的宽高并监听窗口大小变化
            window.addEventListener('resize', () => {
                if (this.player) {
                    this.player.JS_Resize()
                }
            })
        },
        createPlayer() {
            this.player = new window.JSPlugin({
                szId: 'player',
                szBasePath: '/',
                iMaxSplit: this.maxSplit,
                iCurrentSplit: this.currentSplit,
                openDebug: true,
                oStyle: {
                    borderSelect: '#FFCC00',
                },
            })
            this.init()
            // 事件回调绑定
            this.player.JS_SetWindowControlCallback({
                windowEventSelect: function (iWndIndex) {
                    //插件选中窗口回调
                    console.log('windowSelect callback: ', iWndIndex)
                },
                pluginErrorHandler: function (iWndIndex, iErrorCode, oError) {
                    //插件错误回调
                    console.log(
                        'pluginError callback: ',
                        iWndIndex,
                        iErrorCode,
                        oError
                    )
                },
                windowEventOver: function (iWndIndex) {
                    //鼠标移过回调
                    //console.log(iWndIndex);
                },
                windowEventOut: function (iWndIndex) {
                    //鼠标移出回调
                    //console.log(iWndIndex);
                },
                windowEventUp: function (iWndIndex) {
                    //鼠标mouseup事件回调
                    //console.log(iWndIndex);
                },
                windowFullCcreenChange: function (bFull) {
                    //全屏切换回调
                    console.log('fullScreen callback: ', bFull)
                },
                firstFrameDisplay: function (iWndIndex, iWidth, iHeight) {
                    //首帧显示回调
                    console.log(
                        'firstFrame loaded callback: ',
                        iWndIndex,
                        iWidth,
                        iHeight
                    )
                },
                performanceLack: function () {
                    //性能不足回调
                    console.log('performanceLack callback: ')
                },
            })
        },
        onChangeWdnNum(item) {
            let splitNum = item
            this.player.JS_ArrangeWindow(splitNum).then(
                () => {
                    console.log(
                        `arrangeWindow to ${splitNum}x${splitNum} success`
                    )
                },
                (e) => {
                    console.error(e)
                }
            )
        },
        onSetFull() {
            this.player.JS_FullScreenDisplay(true).then(
                () => {
                    console.log(`wholeFullScreen success`)
                },
                (e) => {
                    console.error(e)
                }
            )
        },
    },
    beforeDestroy() {},
}
</script>

<style lang="scss" scoped>
.player-wrapper{
    width: 100%;
    height: 100%;
    box-sizing: border-box;
}
.player-window-wrapper{
    width: 100%;
    height: calc(100% - 40px);
    position: relative;
    overflow: hidden;
    box-sizing: border-box;
}
.h5-play-wrap {
    width: 100%;
    height: 100%;
    background-color: #000;
    border: 1px solid #333;
    box-sizing: border-box;
    position: relative;
    overflow: hidden;
}
.tool-bar-wraper{
    position: relative;
    height: 40px;
    width: 100%;
    box-sizing: border-box;
    background-color: rgba(0,0,0,0.6);
    z-index: 0;
}
.btn-icon{
    font-size: 20px;
    color: #cecece;
    margin: 10px 5px;
    cursor: pointer;
}
.btn-icon:hover{
    color: #e0e0e0;
}
.el-icon-rank{
    font-size: 22px;
    transform: rotate(45deg);
}
.video_loading{
    position: absolute;
    top: 0;
    left: 0;
    color: #fff;
}
</style>
<style lang='scss'>
.window-type{
    background-color: #333;
    border-color:#333;
    min-width:120px !important;
    width: 120px!important;
}
</style>